# Placeholder Text

Bayesian algorithm for calibration of radiometer devices

Base methodology:
https://arxiv.org/abs/2011.14052

Please cite:
https://academic.oup.com/mnras/article/505/2/2638/6279678

I L V Roque, W J Handley, N Razavi-Ghods, Bayesian noise wave calibration for 21-cm global experiments, \textit{Monthly Notices of the Royal Astronomical Society}, Volume 505, Issue 2, August 2021, Pages 2638–2646, https://doi.org/10.1093/mnras/stab1453
